@@ -30,11 +30,11 @@
     stop("Install the latest version of rstan")
   }
 
-  packageStartupMessage("Version: 0.1.0\n\nIt is a demo.")
+  packageStartupMessage("Version: 1.0.0\n\nIt is a demo.\nAcknowledgements. It is supported by the Institute of Education Sciences, U.S. Department of Education, through Grant R305D210036.")
 
 }
 
-globalVariables(c("custom_data", "custom_stan"))
+# globalVariables(c("compiled_stan"))
 
 #' #' @noRd
 #' .onLoad <- function(...) {
